@@ -29,17 +29,8 @@ import os
 import webbrowser
 
 def show_cam():
-    #print(camera_ins)
-    #global camera
-    #print(camera)
-    """
-    vidnum = number; res 640x480;
-    recommended= ... uses the recommend_video to restart the same cam
-    """
 
-    # print(f"i...  target_frame = {target_frame}, average={average}, blur={blur}")
     camera = Camera( ) # creating the OBJECT
-    #print("direct = camera", camera, "  (web)camera",camera_ins)
 
     framecnt = 0
     framecnttrue = 0
