@@ -47,20 +47,13 @@ class Camera(BaseCamera):
 
 
         # res = "640x480"
-        res = config.CONFIG["resolution"]
+        res = config.CONFIG["res"]
         print("D... init_cam caleld with:", res )
         print("i... init_cam caleld with:", res )
-        print("D... init_cam caleld with:",  config.CONFIG["recommended"] )
-        print("i... init_cam caleld with:",  config.CONFIG["recommended"] )
+        print("D... init_cam caleld with:",  config.CONFIG["product"] )
+        print("i... init_cam caleld with:",  config.CONFIG["product"] )
 
-        # vids = []
-        # while len(vids)==0:
-        #     vids = recommend_video( config.CONFIG["recommended"]  )
-        #     if len(vids)==0:
-        #         print("!... NO VIDEO was recommended.",vids," sleeping 3 sec, locked in loop")
-        #         time.sleep(4)
-        #         # sys.exit()
-        vids = recommend_video( config.CONFIG["recommended"]  )
+        vids = recommend_video( config.CONFIG["product"]  )
 
         if len(vids)>0:
             vidnum = vids[0]
@@ -89,7 +82,7 @@ class Camera(BaseCamera):
     @staticmethod
     def frames( ):
         """
-        recommended= ... uses the recommend_video to restart the same cam
+        product= ... uses the recommend_video to restart the same cam
         """
         # i need these to be in globals() ----evaluate from web.py
         global substract_background,save_background
@@ -99,21 +92,27 @@ class Camera(BaseCamera):
         global expo_divide,expo_multiply,expo_setdef
         global timelaps, rotate180
         global fixed_image # show not camera but image
+        global zoom
 
         # print("i... staticmethod frames @ real -  enterred; target_frame==", target_frame)
         senh = Stream_Enhancer()
 
+        # === I must have these GLOBAL and PREDEFINED HERE <= web.py
+        # --------------------------------  control
         # -----------get parameters for DetMot, same for web as for all
-        target_frame = config.CONFIG['target_frame']
+        #print(config.CONFIG)
+        #print( "AVERAGE I AM HAVING ",config.CONFIG['average'] )
+        framekind = config.CONFIG['framekind']
         average      = int(config.CONFIG['average'])
         threshold    = int(config.CONFIG['threshold'])
         blur         = int(config.CONFIG['blur'])
-        timelaps     = int(config.CONFIG['timelaps'])
+        timelaps     = int(config.CONFIG['laps'])
         histogram    = config.CONFIG['histogram']
-        res          = config.CONFIG['resolution']
+        res          = config.CONFIG['res']
         speedx       = float(config.CONFIG['x'])
         speedy       = float(config.CONFIG['y'])
-        rotate180    = config.CONFIG['rotate180']
+        rotate180    = int(config.CONFIG['otate'])
+        zoom         = int(config.CONFIG['zoom'])
 
         # ------------------    to evaluate commands from web.py
         substract_background = False
@@ -163,7 +162,7 @@ class Camera(BaseCamera):
         # I CALL SET_GAM from
         set_gem(cc, config.CONFIG['gain'],
                 config.CONFIG['expo'],
-                config.CONFIG['gamma'])
+                config.CONFIG['mmaga'])
 
 
         # very stupid camera    ZC0303 Webcam
@@ -190,10 +189,10 @@ class Camera(BaseCamera):
 
 
         nfrm = 0
-        if config.CONFIG["recommended"]:
+        if config.CONFIG["product"]:
             wname = "none "
         else:
-            wname = config.CONFIG["recommended"]
+            wname = config.CONFIG["product"]
 
 
         frame_prev = None
@@ -230,9 +229,6 @@ class Camera(BaseCamera):
 
             if not ret:
                 time.sleep(0.5)
-                #vids = recommend_video(recommended) # try to re-init the same video
-                #if len(vids)>0:
-                #    vidnum = vids[0]
                 config.CONFIG["camera_on"] = False
 
                 cap = Camera.init_cam( )
@@ -300,6 +296,25 @@ class Camera(BaseCamera):
                             gammadef = cc.getdef_gamma()
                     #--------------------------------------------------------------------------
 
+                    #=========== BEFORE OTHER === Create final image ====
+                    #=========== like ZOOM
+                    #=========== THEN CALCULATE HISTO =====
+                    #=========== THEN do other stuff
+                    # senh has a frame now
+                    if rotate180!=0:   # rotate earlier than zoom
+                        senh.rotate180( rotate180 ) #arbitrary int angle
+
+                    if zoom!=1:
+                    #if int(config.CONFIG['zoom'])!=1:
+                        try:
+                            crocfg = os.path.expanduser("~/.config/flashcam/cross.txt")
+                            cross_dx, cross_dy  = None, None
+                            if os.path.exists(crocfg):
+                                with open(crocfg) as f:
+                                    cross_dx, cross_dy  = [int(x) for x in next(f).split()]
+                                    senh.zoom( zoom ,cross_dx, cross_dy )
+                        except Exception as e:
+                            print("!... Problem ar cross.txt file:",e)
 
                     # ----------  I need to calculate histogram before labels...
                     if histogram: # just calculate a number on plain frame
@@ -320,9 +335,6 @@ class Camera(BaseCamera):
                     # globals()["substract_background"] = value
 
 
-                    if rotate180:
-                        senh.rotate180()
-
 
                     if save_background:
                         print("D... HERE I SAVE save_background of mask")
@@ -412,8 +424,8 @@ class Camera(BaseCamera):
                     #--------------- now apply labels ------i cannot get rid in DETM---
                     #--------- all this will be on all rames histo,detect,direct,delta
                     senh.setbox(" ", senh.TIME)
-                    if target_frame in ["detect","delta","histo"]:
-                        senh.setbox(f"DISP {target_frame}",senh.DISP)
+                    if framekind in ["detect","delta","histo"]:
+                        senh.setbox(f"DISP {framekind}",senh.DISP)
                     if average>0:
                         senh.setbox(f"acc {average}",  senh.avg)
                     if blur>0:
@@ -429,9 +441,11 @@ class Camera(BaseCamera):
                         senh.setbox(f"x {speedx:.3f}",  senh.speedx)
                     if speedy!=0:
                         senh.setbox(f"y {speedy:.3f}",  senh.speedy)
+                    if zoom!=1:
+                        senh.setbox(f"z {zoom:1d}x", senh.scale)
                     if substract_background:
                         senh.setbox("-BCKG",  senh.SUBBG )
-                    if rotate180:
+                    if rotate180!=0:
                         senh.setbox("ROT",  senh.rot )
 
 
@@ -467,7 +481,7 @@ class Camera(BaseCamera):
                         #senh.setbox("MODE  ", senh.MODE)
 
                     # ---draw histogram
-                    if target_frame == "histo":
+                    if framekind == "histo":
                         senh.histo( )
 
                     if timelaps>0:
@@ -476,8 +490,8 @@ class Camera(BaseCamera):
 
 
                     #------------yield the resulting frame-----------------------------
-                    if target_frame in ["detect","delta","histo"]:
-                        frame = senh.get_frame(  typ = target_frame)
+                    if framekind in ["detect","delta","histo"]:
+                        frame = senh.get_frame(  typ = framekind)
                     else:
                         frame = senh.get_frame(  )
 
