@@ -51,6 +51,7 @@ class Stream_Enhancer:
     avi = (8,0) #
     jpg = (9,0) #
 
+    scale = (10,0) #? see
 
     delta_frame = None
     detect_frame = None
@@ -108,6 +109,7 @@ class Stream_Enhancer:
         if (row,col) == self.speedy: return (80,180,80) #
         if (row,col) == self.avi:    return (30,30,210) # FOR UNI only
         if (row,col) == self.jpg:    return (0,0,250)   # FOR UNI only
+        if (row,col) == self.scale:  return (250,0,250)   # zoom scale
 
         t=[255,255,255]
         while (t[0]+t[1]+t[2]>400) or  (t[0]+t[1]+t[2]<200) :
@@ -226,9 +228,9 @@ class Stream_Enhancer:
 
 
         if target is None:
-            target_frame = self.frame
+            framekind = self.frame
         else:
-            target_frame = target
+            framekind = target
 
 
         self.get_font_params(txt)
@@ -240,10 +242,10 @@ class Stream_Enhancer:
         beginCorner=( pos[0]-1                , pos[1]- self.text_height-1 )
         endCorner  =( pos[0]+self.text_width+1, pos[1]+3   )
 
-        cv2.rectangle(target_frame,
+        cv2.rectangle(framekind,
                       beginCorner, endCorner,
                       bgcolor, cv2.FILLED)
-        cv2.putText(target_frame, txt,
+        cv2.putText(framekind, txt,
                     tuple(pos),
                     self.font,
                     self.fontScale,
@@ -262,9 +264,9 @@ class Stream_Enhancer:
         """
 
         if target is None:
-            target_frame = self.frame
+            framekind = self.frame
         else:
-            target_frame = target
+            framekind = target
 
         row,col=list(rowcol)
         if not self.frame_ok: return
@@ -297,6 +299,8 @@ class Stream_Enhancer:
         if (row==8)and(col==0):  side="left"
         if (row==9)and(col==0):  side="left"
 
+        if (row==10)and(col==0):  side="left"
+
         if side=="" and row>2:
             print("X... Too many rows, (0,1,2 only)")
             return
@@ -329,10 +333,10 @@ class Stream_Enhancer:
                     self.textbox(txt, pos )
                     if NOW.second % 2 == 0:
                         #  fontsize 0.5=> 10   or 0.3 for RPI 320x240
-                        cv2.circle( target_frame, (10,10), int(self.fontScale*18), (0,0,255), -1 )
+                        cv2.circle( framekind, (10,10), int(self.fontScale*18), (0,0,255), -1 )
 
                     else:
-                        cv2.circle( target_frame, (10,10), int(self.fontScale*18), (0,255,0), -1 )
+                        cv2.circle( framekind, (10,10), int(self.fontScale*18), (0,255,0), -1 )
 
                     return
                 if col<3:
@@ -345,13 +349,18 @@ class Stream_Enhancer:
                 pos[1] = self.frame.shape[0] - int(1.5*self.posy_offs)
 
         #print(pos)
-        self.textbox(txt, pos , bgcolor= self.RC_COLOR(row,col) , target = target_frame)
+        self.textbox(txt, pos , bgcolor= self.RC_COLOR(row,col) , target = framekind)
 
     #-------------------------------------------- ENDOF LABELS----------
 
 
-    def rotate180(self):
-        self.frame = cv2.rotate(self.frame, cv2.ROTATE_180)
+    def rotate180(self, angle):
+        if angle == 0:
+            return
+        elif angle == 180:
+            self.frame = cv2.rotate(self.frame, cv2.ROTATE_180)
+        else:
+            self.frame = imutils.rotate(self.frame, angle)
 
     def save_background(self):
         cv2.imwrite( self.BGFILE , self.frame ) # nicely saved
@@ -609,6 +618,40 @@ class Stream_Enhancer:
         #  {min1:.1f} {max1:.1f}
         return mean  #/255*100
 
+    def zoom(self, scale, x=None,y=None):
+        #scale = zoom
+        #get the webcam size
+
+
+        height, width, channels = self.frame.shape
+        #prepare the crop
+        centerX = int(height/2)
+        centerY = int(width/2)
+
+        #if not x is None:
+        #    centerX+= x
+        #if not y is None:
+        #    centerY+= y
+        if (x!=0) or (y!=0):
+            dwidth = -x    #negative up
+            dheight = -y   # positive down
+            T = np.float32([[1, 0, dwidth], [0, 1, dheight]])
+            self.frame = cv2.warpAffine(self.frame, T, (self.frame.shape[1], self.frame.shape[0]))
+
+        # return
+        radiusX,radiusY= int(height/2/scale),int(width/2/scale)
+
+        minX,maxX=centerX-radiusX,centerX+radiusX
+        minY,maxY=centerY-radiusY,centerY+radiusY
+        #minX=max(minX,0)
+        #minY=max(minY,0)
+        #maxX=min(maxX,height)
+        #maxY=min(maxY,width)
+
+        #print(" cut x=",minX,maxX, "  and y=",minY,maxY )
+        cropped = self.frame[minX:maxX, minY:maxY]
+        #print("CENTER:",centerX, centerY,"#",  cropped.shape, scale,"x")
+        self.frame = cv2.resize(cropped, (width, height))
 
 
     def histo(self):
