@@ -255,7 +255,7 @@ def show_cam(vidnum, res, recommended=""):
 
 
 
-def recommend_video( prefname="" ):
+def recommend_video( prefname=None ):
     """
     glob through /dev/video*
     recommend video device:  without paramenter - the list is returned, else if string matches
@@ -320,7 +320,7 @@ def recommend_video( prefname="" ):
                     #print(usb_hubs)
                     vidid = int(vid[vid.find('/dev/video')+10:])
                     pref = " "
-                    if str(prefname) == "":
+                    if prefname is None:
                         recomvid.append( vidid )
                     else:
                         if (name.find(str(prefname))>=0) or (id_path.find(str(prefname))>=0):
@@ -331,7 +331,7 @@ def recommend_video( prefname="" ):
                     # verify_resolutions( vidid, resolutions )
             # print(prefname, recomvid)
     print("|"*80)
-    if str(prefname)!="":
+    if not prefname is None:
         if len(recomvid)==0:
             print("X... config WANTS the camera",prefname)
             print("X... NOT FOUND")
@@ -339,7 +339,7 @@ def recommend_video( prefname="" ):
     # print("i... recommending:",recomvid)
     # print("i... recommending:",recomvid)
     # print("i... recommending:",recomvid)
-    print("i... recommending:",recomvid)
+    print("i... recommending video#:",recomvid[0], " ... full list:", recomvid)
 
     #resolutions = get_resolutions( recomvid[0] )
     # show_cam( recomvid[0], resolutions[-1] )
