@@ -7,9 +7,13 @@ This is flask interface
 '''
 from flashcam.version import __version__
 from fire import Fire
-from flashcam import config
 
-#--------------------------------------
+from flashcam import config
+config.CONFIG['filename'] = "~/.config/flashcam/cfg.json"
+config.load_config()
+# print(config.CONFIG)
+# print("------------JUST LOADED---------------")
+
 
 from importlib import import_module
 import os
@@ -66,28 +70,32 @@ app = Flask(__name__)
 
 
 #==================== ALL config changes must be here ============
-#  1st 'filename'   2nd load !!!!!!!!!!!!!!!!!
-print( "i... USER  web:", config.CONFIG['user'] )
-config.CONFIG['filename'] = "~/.config/flashcam/cfg.json"
-config.load_config()
-print( "i... USER  web:", config.CONFIG['user'] )
+#
+#  1st   'filename'     2nd load config       !!!!!!!!!!!!!!!!!
+#
+#config.CONFIG['filename'] = "~/.config/flashcam/cfg.json"
+#config.load_config()
 
-config.CONFIG['camera_on'] = False # for everyone - nobodyhas the camera at this point
+#
+config.CONFIG['camera_on'] = False # for everyone -
+#               nobodyhas the camera at this point
+#               ?? it is used in real_camera.py ...
+#
 if  not("debug" in config.CONFIG):
     config.CONFIG['debug'] = True
 
 
+
 #config.show_config()
-
 # CONFIG WILL BE SAVED WHEN RUN FROM MAIN
 
-
 # Camera = Camera #  This was a lucky error.... CLass from Class
 # it appears - flask works when I run directly the class .....
 
 
 cross_dx, cross_dy = 0,0
 cross_on = False
+zoom2_on = 1
 
 save_bg = False
 frame_bg = None
@@ -109,13 +117,12 @@ def logthis( ttt="Started" ):
         f.write( sss )
 
 
-logthis()
+logthis() #-------- keep track about logins ---------
 remote_ip=""
 auth = HTTPBasicAuth()
 
 #---not fstring- {} would colide
 
-
 index_page = """
  <!--meta http-equiv="refresh" content="5";-->
 
@@ -167,7 +174,7 @@ setInterval(doDate, 200);
   </div>
   <div class="btn-group" style="width:100%">
       <button style="width:20%" name="down2" value="DOWN2">down2</button>
-  </div>
+<button style="width:10%" name="zoom2" value="ZOOM2">ZOOM2</button> </div>
 <hr>
 
 <table>
@@ -225,7 +232,6 @@ setInterval(doDate, 200);
 </form>
 
 
-
   </body>
 </html>
 
@@ -255,7 +261,7 @@ def crossonw( img,  dix, diy):
 @auth.verify_password
 @app.route("/cross", methods=['GET', 'POST'])
 def cross():
-    global cross_dx, cross_dy, cross_on, save_bg, sub_bg
+    global cross_dx, cross_dy, cross_on, save_bg, sub_bg, zoom2_on
 
     # i will read it from file
     crocfg = os.path.expanduser("~/.config/flashcam/cross.txt")
@@ -344,9 +350,9 @@ def cross():
                 print("D... unknown value timelaps")
 
         if request.form.get('rot0') == 'ROT0':
-            mmwrite(f"rotate180 False" )
+            mmwrite(f"rotate180 0" )
         if request.form.get('rot180') == 'ROT180':
-            mmwrite(f"rotate180 True" )
+            mmwrite(f"rotate180 180" )
 
         if request.form.get('live') == 'LIVE':
             mmwrite(f"fixed_image None" )
@@ -426,6 +432,24 @@ def cross():
             print("OFF")
             cross_on = False
 
+        if  request.form.get('zoom2') == 'ZOOM2':
+            if zoom2_on==1:
+                print("ZOOM2 ->2")
+                zoom2_on = 2
+                mmwrite(f"zoom 2" )
+            elif zoom2_on==2:
+                print("ZOOM2 ->4")
+                zoom2_on = 4
+                mmwrite(f"zoom 4" )
+            elif zoom2_on==4:
+                print("ZOOM2 ->6")
+                zoom2_on = 8
+                mmwrite(f"zoom 8" )
+            else :
+                print("ZOOM2 ->1")
+                zoom2_on = 1
+                mmwrite(f"zoom 1" )
+
         # .... save cross x and y inside a file at ~/.config/flashcam/
         with open(crocfg,"w") as f:
             f.write(f"{cross_dx} {cross_dy}")
@@ -590,7 +614,10 @@ def gen(camera, remote_ip, blend=False, bigtext=True):
             frame = 0.5*frame + 0.5*imgs[ random.randint(0,len(imgs)-1) ]
 
         if cross_on:
-            frame = crossonw( frame, cross_dx, cross_dy )
+            if zoom2_on==1:
+                frame = crossonw( frame, cross_dx, cross_dy )
+            else:
+                frame = crossonw( frame, 0,0  )
 
         # if save_bg:# before .tobytes()
         #     cv2.imwrite( BGFILE , frame )
@@ -632,6 +659,5 @@ def gen(camera, remote_ip, blend=False, bigtext=True):
 
 if __name__ == '__main__':
 
-
     print("i... APP RUN FROM WEB.PY")
     app.run(host='0.0.0.0', port=config.CONFIG['port'], threaded=True)
